@@ -70,6 +70,11 @@ DIR *      bolt_opendir_at (int         dirfd,
 gboolean   bolt_closedir (DIR     *d,
                           GError **error);
 
+gboolean   bolt_mkdirat (int         dirfd,
+                         const char *name,
+                         mode_t      mode,
+                         GError    **error);
+
 gboolean   bolt_rmdir (const char *name,
                        GError    **error);
 
@@ -87,6 +92,12 @@ gboolean   bolt_unlink_at (int         dirfd,
                            int         flag,
                            GError    **error);
 
+gboolean   bolt_write_file_at (int         dirfd,
+                               const char *name,
+                               const char *data,
+                               gssize      len,
+                               GError    **error);
+
 char *     bolt_read_value_at (int         dirfd,
                                const char *name,
                                GError    **error);
@@ -96,11 +107,26 @@ gboolean   bolt_write_char_at (int         dirfd,
                                char        value,
                                GError    **error);
 
+gboolean   bolt_write_int_at (int         dirfd,
+                              const char *name,
+                              gint        val,
+                              GError    **error);
+
 gboolean   bolt_read_int_at (int         dirfd,
                              const char *name,
                              gint       *val,
                              GError    **error);
 
+gboolean   bolt_write_uint_at (int         dirfd,
+                               const char *name,
+                               guint       val,
+                               GError    **error);
+
+gboolean   bolt_read_uint_at (int         dirfd,
+                              const char *name,
+                              guint      *val,
+                              GError    **error);
+
 gboolean   bolt_verify_uid (int         dirfd,
                             const char *uid,
                             GError    **error);
@@ -141,11 +167,21 @@ gboolean   bolt_rename (const char *from,
                         const char *to,
                         GError    **error);
 
+gboolean   bolt_renameat (int         from_dir,
+                          const char *from,
+                          int         to_dir,
+                          const char *to,
+                          GError    **error);
+
 gboolean   bolt_copy_bytes (int      fd_from,
                             int      fd_to,
                             size_t   len,
                             GError **error);
 
+gboolean   bolt_dir_is_empty (DIR      *dir,
+                              gboolean *empty,
+                              GError  **error);
+
 /* auto cleanup for I/O handles */
 void       bolt_cleanup_close_intpr (int *fd);
 #define    bolt_autoclose bolt_cleanup (bolt_cleanup_close_intpr)
